@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 . ./common.sh
 
@@ -11,7 +11,7 @@ case "$1" in
 		mkdir -p release/atari/debian
 		cp resc1440atari.bin release/atari/debian/resc1440.bin
 		cp drv1440atari.bin release/atari/debian/drv1440.bin
-		cp linuxatari release/atari/debian/linux
+		cp linuxatari.bin release/atari/debian/linux.bin
 		cp sys_mapatari.gz release/atari/debian/sysmap.gz
 		cp rootatari.bin release/atari/debian/root.bin
 		cp m68k-specials/bootstra.ttp release/atari/debian/bootstra.prg
@@ -35,7 +35,7 @@ EOF
 		(cd release/amiga/ && lha x ../../m68k-specials/amiga-kit.lzh)
 		cp resc1440amiga.bin release/amiga/debian/resc1440.bin
 		cp drv1440amiga.bin release/amiga/debian/drv1440.bin
-		cp linuxamiga release/amiga/debian/linux
+		cp linuxamiga.bin release/amiga/debian/linux.bin
 		cp sys_mapamiga.gz release/amiga/debian/
 		cp rootamiga.bin release/amiga/debian/root.bin
 		# create lzh archive
@@ -55,7 +55,7 @@ EOF
 		# mount it (':' is top dir)
 		hmount release/macinstall-floppy-hfs.img
 		# copy kernel/sysmap/ramdisk as raw
-		hcopy -r linuxmac :linux
+		hcopy -r linuxmac.bin :linux.bin
 		hcopy -r sys_mapmac.gz :System-Map.gz
 		hcopy -r rootmac.bin :root.bin
 		# copy booter as BinHex (MacBinary: -m)
@@ -75,7 +75,7 @@ EOF
 		## mount it (':' is top dir)
 		#hmount release/macinstall-hfs.img
 		## copy kernel/sysmap/ramdisk as raw
-		#hcopy -r linuxmac :linux
+		#hcopy -r linuxmac.bin :linux.bin
 		#hcopy -r sys_mapmac.gz :System-Map.gz
 		#hcopy -r rootmac.bin :root.bin
 		#hcopy -r resc1440mac.bin :resc1440.bin
