@@ -13,7 +13,7 @@ hmount $image
 hcopy powerpc-specials/miBoot/Finder.bin :
 hcopy powerpc-specials/miBoot/System.bin :
 
-hcopy -r linuxpmac.gz :zImage
+hcopy -r linuxpmac.bin.gz :zImage
 
 # There's no longer enough room on the HFS disk for this :(  No real loss.
 #gzip -dc sys_mappmac.gz > .S
