@@ -235,7 +235,7 @@ do_arch_i386()
     done
   done
 
-  cp xlp.tgz $release
+  [ -f xlp.tgz ] && cp xlp.tgz $release
 
   # DOS tools provided for i386 only
   recode latin1..ibmpc <scripts/dos/install.bat >$release/install.bat
@@ -361,10 +361,11 @@ do_arch_sparc()
     # a.out (required by the SUN TFTP boot process) and pad the result to
     # be 4-bytes aligned (required by some old bootproms).
     info "making linux${subarch}.bin safe for TFTP uses"
-    gzip -dcf $release/linux${subarch}.bin > $release/${subarch}/linux.bin
+    mv $release/linux${subarch}.bin $release/${subarch}/vmlinuz
+    gzip -dcf $release/${subarch}/vmlinuz > $release/${subarch}/linux.bin
     elftoaout -o $release/${subarch}/linux-a.out $release/${subarch}/linux.bin ||
         mv $release/${subarch}/linux.bin $release/${subarch}/linux-a.out
-    rm -f $release/linux${subarch}.bin $release/${subarch}/linux.bin
+    rm -f $release/${subarch}/linux.bin
     size=`ls -l release/${subarch}/linux-a.out | awk '{print $5}'`
     if rem=`expr \( 4 - $size % 4 \) % 4`; then
         dd if=/dev/zero bs=1 count=$rem >> $release/${subarch}/linux-a.out
@@ -1066,6 +1067,9 @@ do_arch_arm()
 
   # delete empty directories
   rmdir $release/images-1.44 $release/images-2.88
+
+  # delete any spare kernels that might be lying around
+  rm -f $release/linux*.bin
   )
 }
 
@@ -1180,7 +1184,7 @@ do_arch_mips()
     mv $release/drivers${subarch}.tgz $release/${subarch}/drivers.tgz
     # kernel + tftp boot image
     gunzip -c config${subarch} > $release/${subarch}/kernel-config
-    cp -a  linux${subarch}.bin $release/${subarch}/linux.bin
+    mv ${release}/linux${subarch}.bin $release/${subarch}/linux.bin
     cp tftpboot-${subarch}.img $release/${subarch}/tftpboot.img
   done
 
@@ -1313,7 +1317,7 @@ do_arch_s390()
  
   # not needed on s390
   rm -rf $release/images-2.88
-  rm -f $release/images-1.44/drivers390-1.bin
+  rm -f $release/images-1.44/drivers390-1.bin $release/linux*.bin
 
   # make md5sum before tarring up all the contents
   (cd $release && md5sum `find . -type f |                      \
