@@ -440,11 +440,7 @@ case "$arch" in
 	# They come with the silo package, for our convienience.
 	#
 	tmp=${tmpdir}/boot-floppies/silo_proto.$$
-	if [ ${subarch} = "sun4dm-pci" ]; then
-            silokver="-sun4cdm"
-	else
-            silokver="-${subarch}"
-	fi
+        silokver="-${subarch}"
 	info "downloading silo"
 	silopkg=`grab_paths silo`
 	debug "extracting $silopkg"
