@@ -406,10 +406,15 @@ then
 		< $scripts/prototype/etc/inittab > $T/etc/inittab
 	cat <<EOF >> $T/sbin/udbootstrap
 #!/bin/sh
-if (</dev/fb0) 2>/dev/null && ! grep -q console=ttyS /proc/cmdline 2> /dev/null ; then
-export LC_CTYPE=C@utf-8 
+if (</dev/fb0) 2>/dev/null && \
+	! grep -q console=ttyS /proc/cmdline 2> /dev/null && \
+	! grep -q nolangchooser /proc/cmdline 2> /dev/null ; then
+LC_CTYPE=C@utf-8
+export LC_CTYPE
 exec /usr/bin/bterm -f /unifont-reduced.bgf /sbin/dbootstrap
 fi
+TERM=vt102
+export TERM
 exec /sbin/dbootstrap
 EOF
 	chmod a+rx $T/sbin/udbootstrap
@@ -1007,6 +1012,7 @@ elif  [ "$arch" = i386 -a "$revext" = "bf2.4" ]; then
   include_module $mnt/lib/modules/$kver-bf2.4/kernel/drivers/usb/usb-uhci.o
   include_module $mnt/lib/modules/$kver-bf2.4/kernel/drivers/usb/usb-ohci.o
   include_module $mnt/lib/modules/$kver-bf2.4/kernel/drivers/usb/usbkbd.o
+#  include_module $mnt/lib/modules/$kver-bf2.4/kernel/drivers/usb/usb-storage.o
   include_module $mnt/lib/modules/$kver-bf2.4/kernel/drivers/input/input.o || true
   include_module $mnt/lib/modules/$kver-bf2.4/kernel/drivers/input/keybdev.o
 fi
