@@ -1,11 +1,6 @@
-#!	/bin/sh
+#!	/bin/bash
 
-# Abort on any non-zero return.
-set -e
-
-# Verbose shell execution.
-#set -x
-#set -v
+. ./common.sh
 
 # Print a usage message and exit if the argument count is wrong.
 if [ $# != 2 ]; then
@@ -21,22 +16,15 @@ fi
 oldf=$1
 newf=$2
 
-mnt=/var/tmp/mnt.$$
-
-loopdevice=/dev/loop3
+info "making safe version of $oldf in $newf"
 
+relax
 cp $oldf $newf.tmp
-
-(umount $loopdevice; true)
-(/sbin/losetup -d $loopdevice; true)
-
-/sbin/losetup $loopdevice $newf.tmp
-
-syslinux -s $loopdevice
-
-/sbin/losetup -d $loopdevice
-
-(rm -f -r $newf;true)
+relax
+syslinux -s $newf.tmp
+rm -rf $newf
 mv $newf.tmp $newf
+
+info "safe image complete:"
 ls -l $newf
 exit 0
