@@ -1,22 +1,21 @@
 #!	/bin/sh
 
-. ./common.sh
+set -e
 
 if [ $# -lt 1 ]; then
-	echo "Usage: $0 file [file ...]" 1>&2
-	echo 1>&2
-	echo "	Strip any executable files in the argument list, leave" 1>&2
-	echo "	other kinds of files alone." 1>&2
-	exit -1
+    echo "usage: $0 file [file ...]" 1>&2
+    echo 1>&2
+    echo "strip any executable files in the argument list, leave" 1>&2
+    echo "other kinds of files alone." 1>&2
+    exit -1
 fi
 
 EXECUTABLES=`file $* | grep ELF | sed 's/:.*$//'`
 
-for EXECUTABLE in ${EXECUTABLES}; do
-    if [ -z $EXECUTABLE ]; then
-        error no ELF executables to strip
-    fi
-done
+if [ -z "$EXECUTABLES" ]; then
+    echo "error: no ELF executables to strip" 1>&2
+    exit 1
+fi
 
 # _dl_debug_state is a symbol of ld-linux.so that is used by GDB to breakpoint
 # debug dynamicaly-loaded code. I explicitly keep it here. There will no doubt
@@ -25,5 +24,4 @@ done
 
 strip --remove-section=.note --remove-section=.comment --keep-symbol _dl_debug_state $EXECUTABLES
 
-
 exit 0
