@@ -317,18 +317,18 @@ static int write_fstab (void) {
   }
   else if (is_fstype("/target", "ext3")) {
     fsname = "ext3";
-    fsopts = "defaults,errors=remount-ro";
+    fsopts = "errors=remount-ro";
     pass = 1;
   }
   else if (is_fstype("/target", "ext2")) {
     fsname = "ext2";
-    fsopts = "defaults,errors=remount-ro";
+    fsopts = "errors=remount-ro";
     pass = 1;
   }
   else if (is_fstype("/target", "reiserfs")) {
     fsname = "reiserfs";
     if (need_notail("/target"))
-      fsopts = "defaults,notail";
+      fsopts = "notail";
     else
       fsopts = "defaults";
     pass = 0; /* fsck is unusable */
@@ -341,7 +341,7 @@ static int write_fstab (void) {
   fprintf(fstab,
 	  _("# /etc/fstab: static file system information.\n"
 	    "#\n"
-	    "# <file system>\t<mount point>\t<type>\t<options>\t\t\t<dump>\t<pass>\n"));
+	    "# <file system>\t<mount point>\t<type>\t<options>\t\t<dump>\t<pass>\n"));
   fprintf(fstab,
 	  "%s\t/\t\t%s\t%s\t0\t%d\n",
 	  Root->name, fsname, fsopts, pass);
@@ -357,10 +357,10 @@ static int write_fstab (void) {
   }
 
   fprintf(fstab,
-	  "proc\t\t/proc\t\tproc\tdefaults\t\t\t0\t0\n");
+	  "proc\t\t/proc\t\tproc\tdefaults\t\t0\t0\n");
   fprintf(fstab,
-	    "/dev/fd0\t/floppy\t\tauto\tdefaults,user,noauto\t\t0\t0\n"
-	    "/dev/cdrom\t/cdrom\t\tiso9660\tdefaults,ro,user,noauto\t\t0\t0\n");
+	    "/dev/fd0\t/floppy\t\tauto\tuser,noauto\t\t0\t0\n"
+	    "/dev/cdrom\t/cdrom\t\tiso9660\tro,user,noauto\t\t0\t0\n");
 
   proc = fopen ("/proc/mounts", "r");
   if ( proc == NULL )
