@@ -426,6 +426,7 @@ static int firstnumber(const char* boot)
 
 #if #cpu (i386)
 #define DEV_HDA      "/dev/hda"
+#define DEV_I2O_HDA "/dev/i2o/hda"
 #define DEV_SDA      "/dev/sda"
 #define DEV_RD_C0D0  "/dev/rd/c0d0"
 #define DEV_IDA_C0D0 "/dev/ida/c0d0"
@@ -446,6 +447,7 @@ int is_first_scsi(struct fdisk_partition *part)
 		   strcmp(dname, DEV_RD_C0D0)  == 0 ||
          strcmp(dname, DEV_CCISS_C0D0)  == 0 ||
 		   strcmp(dname, DEV_IDA_C0D0) == 0 ||
+		   strcmp(dname, DEV_I2O_HDA) == 0 ||
          strcmp(dname, DEV_ATARAID_D0) == 0);
 }
 
@@ -492,6 +494,11 @@ int is_scsi(const char *name)
 {
   return strncmp(name, DEV_SDA, strlen(DEV_SDA) - 1) == 0;
 }
+/* is_i2o_scsi: returns true if partition is on a i2o-SCSI disk */
+int is_scsii2o(const char *name)
+{
+  return strncmp(name, DEV_I2O_HDA, strlen(DEV_I2O_HDA) - 1) == 0;
+}
 
 /* is_scsird: returns true if partition is on a SCSI disk (/dev/rd/c*) */
 int is_scsird(const char *name)
@@ -1618,7 +1625,7 @@ static int run_dvhtool(void)
   }
   buf[count] = '\0';
   snprintf(prtbuf, sizeof(prtbuf), 
-	"dvhtool -d %s --unix-to-vh /target/%s linux.bin", disk_name, buf );
+	"dvhtool -d %s --unix-to-vh /target/%s linux", disk_name, buf );
   if( execlog(prtbuf, LOG_DEBUG) ) {
 	problemBox(_("Dvhtool failed - cannot continue."),_("Critical Error"));
 	 return 1;
@@ -1983,7 +1990,14 @@ static char * get_ramdisk_size(char *files[25])
 	int i = 0;
 	char * ascii_size;
 	char * tmp = NULL;
-	
+	char *reqfiles[] = {"/sbin/insmod", "/bin/mount", "/bin/umount", "/bin/sh" "/lib/ld-linux.so.2", NULL};
+   
+   while( reqfiles[i] != NULL) {
+		stat(reqfiles[i++],&statbuf);
+		size += statbuf.st_size;
+   }
+   i=0;
+
 	dir = opendir(MOD_SAVE_DIR);
 	/* hopefully only one or two modules in this dir */
 	file = readdir(dir);
@@ -2003,6 +2017,7 @@ static char * get_ramdisk_size(char *files[25])
 	}
 	free(tmp);
 	closedir(dir);
+   
 	size += 4096; /* big buffer for the linuxrc shell script */
 	while ( strcmp(files[i],"") != 0 )
 	{
@@ -2019,87 +2034,10 @@ static char * get_ramdisk_size(char *files[25])
 	return(ascii_size);
 }
 
-static char * get_device_number(char * device)
-{
-	unsigned char major, minor;
-	char *number;
-#if 1
-	unsigned int temp;
-	char *command;
-	FILE *pipe;
-
-	/* FIXME: Can we do something better ? */
-	/* we get the major number of the device */
-	command = malloc(sizeof("expr substr \"`ls -l ") + strlen(device) + sizeof("`\" 35 2"));
-	if ( command == NULL )
-	{
-		problemBox(_("Can't allocate memory"),_("Critical Error"));
-		exit(1);
-	}
-	strcpy(command,"expr substr \"`ls -l ");
-	strcat(command,device);
-	strcat(command,"`\" 35 2");
-	pipe = popen(command,"r");
-	if ( pipe == NULL )
-	{
-		problemBox(_("Can't open pipe"),_("Critical Error"));
-		exit(1);
-	}
-	fscanf(pipe,"%u",&temp);
-	major = (unsigned char) temp;
-	pclose(pipe);
-	/* we change the magic 35 into magic 40 
-	   to get the minor number */
-	command[strlen(command) - 3 ] = '0';
-	command[strlen(command) - 4 ] = '4';
-	pipe = popen(command,"r");
-	if ( pipe == NULL )
-	{
-		problemBox(_("Can't open pipe"),_("Critical Error"));
-		exit(1);
-	}
-	fscanf(pipe,"%u",&temp);
-	minor = (unsigned char) temp;
-	pclose(pipe);
-	number = malloc(sizeof("0x") + 4);
-	if ( number == NULL )
-	{
-		problemBox(_("Can't allocate memory"),_("Critical Error"));
-		exit(1);
-	}
-    free (command); /* Free what we do not need any more */
-#else
-    struct stat buf;
-	
-    if (stat (device, &buf) == 0)
-        if (S_ISCHR (buf.st_mode) || S_ISBLK (buf.st_mode))
-        {
-            major = MAJOR (buf.st_rdev);
-            minor = MINOR (buf.st_rdev);
-        }
-        else
-        {
-            /* FIXME: should the file name be printed here? */
-            problemBox (_("Specified file is not device", _("Critical Error")));
-
-            exit (1);
-        }
-    else
-    {
-        problemBox (_("Cannot stat device", _("Critical Error")));
-
-        exit (1);
-    }
-#endif
-	sprintf(number,"0x%02u%02u",(unsigned int)major,(unsigned int)minor);
-
-	return number;
-}
-
 #define FLOP_TMP_DIR "/tmp/mnt-flop-ramdisk"
 #define FLOP_RAMDISK "/dev/ram8"
 
-int create_ramdisk(char * device_number,char * size)
+int create_ramdisk(char * size)
 {
 	 DIR *dir;
 	 struct dirent * dirent;
@@ -2221,42 +2159,27 @@ int create_ramdisk(char * device_number,char * size)
 	 } 
 	 fclose(fd2);
 	 fprintf(fd,"/bin/mount -t proc proc /proc\n");
-	 fprintf(fd,"echo %s > /proc/sys/kernel/real-root-dev\n",device_number);
 	 fprintf(fd,"/bin/umount /proc\n");
 	 fclose(fd);
 	 /* chmod 755 */
 	 chmod(FLOP_TMP_DIR "/linuxrc",S_IRUSR | S_IXUSR | S_IWUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
 
-	 if (execlog("cp /sbin/insmod " FLOP_TMP_DIR "/sbin",LOG_DEBUG) )
-	 {
-		problemBox(_("Can't copy needed files"),_("Critical Error"));
-		return 1;
-	 }
-	 if (execlog("cp /bin/mount /bin/umount /bin/sh " FLOP_TMP_DIR "/bin",LOG_DEBUG) )
-	 {
-		problemBox(_("Can't copy needed files"),_("Critical Error"));
-		return 1;
-	 }
-	 if (execlog("cp /lib/ld-linux.so.2 /lib/libc.so.6 " FLOP_TMP_DIR "/lib",LOG_DEBUG) )
-	 {
-		problemBox(_("Can't copy needed files"),_("Critical Error"));
-		return 1;
-	 }
+    if (execlog("cp /sbin/insmod " FLOP_TMP_DIR "/sbin",LOG_DEBUG) || 
+          execlog("cp /bin/mount /bin/umount /bin/sh " FLOP_TMP_DIR "/bin",LOG_DEBUG) ||
+          execlog("cp /lib/ld-linux.so.2 /lib/libc.so.6 " FLOP_TMP_DIR "/lib",LOG_DEBUG) )
+    {
+       problemBox(_("Can't copy needed files"),_("Critical Error"));
+       return 1;
+    }
 	 execlog("umount " FLOP_TMP_DIR,LOG_DEBUG);
 	 rmdir(FLOP_TMP_DIR);
-	 command = realloc(command,sizeof("dd < " FLOP_RAMDISK " > /target/boot/initrd.debinstall bs=1k count=") +
-			 strlen(size));
-	 strcpy(command,"dd < " FLOP_RAMDISK " > /target/boot/initrd.debinstall bs=1k count=");
-	 strcat(command,size);
-	 if ( execlog(command,LOG_DEBUG) )
+    sprintf(prtbuf, "gzip -9f < %s > /target/boot/initrd.debinstall", FLOP_RAMDISK);
+	 if ( execlog(prtbuf,LOG_DEBUG) )
 	 {
-		 problemBox("can't dd",_("Critical Error"));
+		 problemBox("can't compress and copy",_("Critical Error"));
 		 return 1;
 	 }
-	 execlog("/target/bin/gzip -9f /target/boot/initrd.debinstall",LOG_DEBUG);
-	 execlog("mv /target/boot/initrd.debinstall.gz /target/boot/initrd.debinstall",LOG_DEBUG);
 	 sync(); /* I do not know if we need this, but this can't harm */
-	 free(command);
 	 return 0;
 }	 
 	 
@@ -2268,7 +2191,6 @@ static int run_lilo(char *boot, int fixmap, struct d_choices *others, int o_numb
   int status = 0, i=0;
 #ifndef _TESTING_
   struct stat statbuf;
-  char * devnumber;
   char * size;
   /* files that we need */
   char  *files[]={
@@ -2305,7 +2227,7 @@ static int run_lilo(char *boot, int fixmap, struct d_choices *others, int o_numb
   bootpart_map = calloc(1, 32);
   if(fixmap==1) {
      /* harddisk with Boot's location */
-     char *bootpart_dev = strndup(Boot->name, 8);
+     char * bootpart_dev = (char *) strndup(Boot->name, 8);
      /* okay, setting real int13 values for the root and boot devices */
 
      sprintf(boot_map,"disk=%s\nbios=0x80\n", first_ide_disk());
@@ -2337,14 +2259,12 @@ static int run_lilo(char *boot, int fixmap, struct d_choices *others, int o_numb
 #ifndef _TESTING_
   if ( NAME_ISDIR(MOD_SAVE_DIR,&statbuf) )
   {
-	 devnumber = get_device_number(Root->name);
 	 size = get_ramdisk_size(files);
-	 if ( create_ramdisk(devnumber,size) )
+	 if ( create_ramdisk(size) )
 	 {
 		 return 1;
 	 }
 	 free(size);
-	 free(devnumber);
 	 fprintf(filep,BC_LILOTEMPLATE2);
   }
 #endif
@@ -2375,6 +2295,8 @@ static int install_mbr(const char* boot, int *installed_mbr)
     device = DEV_RD_C0D0;
   else if (is_scsiida(boot)) 
     device = DEV_IDA_C0D0;
+  else if (is_scsii2o(boot))
+    device = DEV_I2O_HDA;
   else if (is_scsicciss(boot))
     device = DEV_CCISS_C0D0;
   else if (is_ataraid(boot))
@@ -2464,6 +2386,7 @@ int make_bootable(void)
   else if (is_scsi(boot)) device = DEV_SDA;
   else if (is_scsird(boot)) device = DEV_RD_C0D0;
   else if (is_scsiida(boot)) device = DEV_IDA_C0D0;
+  else if (is_scsii2o(boot)) device = DEV_I2O_HDA;
   else if (is_scsicciss(boot)) device = DEV_CCISS_C0D0;
   else if (is_ataraid(boot)) device = DEV_ATARAID_D0;
   else {
@@ -2489,7 +2412,7 @@ int make_bootable(void)
 	  struct fdisk_partition *part = fdisk_find_partition_by_mntpoint("/target/boot");
 	  is_fstype(part ? "/target/boot" : "/target", "xfs");
       })) {
-      if (!yesNoBox(_("The boot file system type is XFS.  In order to make your system "
+      if (!yesNoBox(_("The /boot file system type is XFS.  In order to make your system "
 		      "bootable, LILO can only be installed into the master boot record "
 		      "(MBR), which means LILO will take control of the boot process.\nContinue?"),
 		    _("Warning")))
@@ -2499,13 +2422,13 @@ int make_bootable(void)
       installed_mbr = 1;
   } else {
       opt[0].tag = device;
-      /* TRANS: keep this under one line (about 70 characters) */
+      /* TRANS: keep this under one line (about 63 characters) */
       opt[0].string = _("Install LILO in the MBR (use this if unsure).");
       opt[1].tag = Boot->name;
-      /* TRANS: keep this under one line (about 70 characters) */
+      /* TRANS: keep this under one line (about 63 characters) */
       opt[1].string = _("Install LILO in the boot partition's boot sector.");
       if (Boot == Root)
-	  /* TRANS: keep this under one line (about 70 characters) */
+	  /* TRANS: keep this under one line (about 63 characters) */
 	  opt[1].string = _("Install LILO in the root partition's boot sector.");
       snprintf(prtbuf, sizeof(prtbuf), _("LILO can be installed either into the master boot record (MBR), or into the %s boot block. If installed into the MBR, LILO will take control of the boot process. If you choose not to install LILO into the MBR, you will have the opportunity later on to install an alternative MBR program (for bootstrapping LILO).\n"),
 	       Boot->name);
@@ -2625,12 +2548,15 @@ nextone:
         struct d_choices options[3];
         options[0].tag = _("Include");
         options[0].state = 0;
+        /* TRANS: keep this under one line (about 63 characters) */
         options[0].string = _("Put all into the menu");
         options[1].tag = _("View");
         options[1].state = 0;
+        /* TRANS: keep this under one line (about 63 characters) */
         options[1].string = _("Show the list of bootable partitions");
         options[2].tag = _("Ignore");
         options[2].state = 0;
+        /* TRANS: keep this under one line (about 63 characters) */
         options[2].string = _("Do not include any other partition");
 redisplay_options:
         status = menuBox(_("LILO setup discovered boot signatures on other partitions in your system. If you installed other operating systems on this machine, you may want to include them in the boot menu. Please choose how to handle them: "), _("Other bootable partitions"), options, 3, 0);
@@ -2638,7 +2564,21 @@ redisplay_options:
            case 0:
               break;
            case 1:
-              menuBox(_("Following partitions are bootable: "), _("Other bootable partitions"), bootable, boot_number, 1);
+              { 
+                 char * buf;
+                 int i;
+                 buf = (char *) calloc (boot_number, 50);
+                 for(i=0; i< boot_number; i++) {
+                    strcat(buf, "\t");
+                    strcat(buf, bootable[i].tag);
+                    strcat(buf, "(");
+                    strcat(buf, bootable[i].string);
+                    strcat(buf, ")\n");
+                 }
+                 sprintf(prtbuf, _("The following partitions seem to be bootable and would be added to the boot menu:\n\n%s"), buf);
+                 problemBox(prtbuf, _("Other bootable partitions"));
+                 free(buf);
+              }
               goto redisplay_options;
            case 2:
               boot_number=0;
