@@ -915,7 +915,7 @@ void debcdrom_prompt (void) {
    buf = (char *) calloc(4096, 1);
    /* rescan the old data before bothering the user */
    find_debian_cdrom(&new_kernel, &new_base);
-   DEBUGMSG("neuer_kernel: %s, neues_basse: %s", new_kernel, new_base);
+   DEBUGMSG("new kernel source: %s, new base source: %s", new_kernel, new_base);
    if( (save_compare(new_kernel, kernel_cd) || save_compare(new_base, base_cd)) )
    {
       /* yeah, something has changed */
@@ -1234,7 +1234,7 @@ static int choose_harddisk(void)
 	snprintf(prtbuf, sizeof(prtbuf),
 		 _("Please indicate where you would like to save your problem report "
 		   "within the filesystem you just mounted.\n\nNote that the filesystem "
-		   "you just mounted is located in the directory %s; the path you enter "
+		   "you just mounted is located in the directory %s; and that the path you enter "
 		   "will be relative to that."),
 		 CM_MOUNTPOINT_DIR);
 	status = choose_problem_dir(prtbuf, CM_MOUNTPOINT_DIR);
@@ -1242,7 +1242,7 @@ static int choose_harddisk(void)
 	snprintf(prtbuf, sizeof(prtbuf),
 		 _("Please indicate the location of the Debian Archive within the filesystem "
 		   "you just mounted.\n\nNote that the filesystem you just mounted is located "
-		   "in the directory, %s; the path you enter will be relative to that."),
+		   "in the directory %s; and that the path you enter will be relative to that."),
 		 CM_MOUNTPOINT_DIR);
 	status = choose_archive_dir(prtbuf, CM_MOUNTPOINT_DIR);
     }
