@@ -245,7 +245,7 @@ exec_debootstrap(char **argv){
     return 0;
 }
 
-#define BASESUITE "testing" /* FIXME: change to stable for release */
+#define BASESUITE "woody" /* FIXME: change to stable for release */
 
 int 
 debootstrap_extract_base (void) {
