@@ -18,7 +18,7 @@ extern int patidx;
 
 char *driver_filenames[] = { "drv12", "drv14", "drv14compact", "drv14idepci", 
 	"drv14ide", "drv14bf2.4", "drv14pmac", "drv14chrp", "drv14prep", 
-	"drv14apus", "drv14sun4cdm", "drv14sun4u", "drv14sun4dm-pci",
+	"drv14apus", "drv14sun4cdm", "drv14sun4u",
         "drv14generic", "drv14jensen", "drv14nautilus", "drv14riscpc", "drv14netwinder", NULL };
 
 static char*
@@ -28,13 +28,13 @@ copy_to_local(const char* diskimage)
   int status;
   if (is_nfs_partition("/target")) {
     /* if nfs-root, cannot copy to local.  Instead use a ramdisk */
-    sprintf(prtbuf, "dd < %s/%s > /dev/ram 2> /dev/null",Archive_Dir,diskimage);
+    sprintf(prtbuf, "dd < %s > /dev/ram 2> /dev/null", diskimage);
     status = execlog(prtbuf, LOG_INFO);
     dev = "/dev/ram";
   }
   else {
     int ro=1;
-    sprintf(prtbuf,"cp %s/%s /target/image.bin",Archive_Dir,diskimage);
+    sprintf(prtbuf,"cp %s /target/image.bin", diskimage);
     status = execlog(prtbuf, LOG_INFO);
     if (status < 0)
       return NULL;
@@ -277,8 +277,9 @@ int choose_and_install(void) {
     } else {
       /* we are not installing from a floppy, maybe it's a file on a local
        * disk or NFS partition */
-      sprintf(prtbuf, "%s/%s", Archive_Dir, kernel_image_path);
-      device = get_device(prtbuf);
+      char *diskimage = concat_paths(Archive_Dir, kernel_image_path);
+      device = get_device(diskimage);
+      free(diskimage);
       if (device) {
 	status = install_floppy(device, "rescue", _("Rescue Floppy Image"));
 	release_device(device);
