@@ -43,12 +43,6 @@ TODO
 #include "util.h"
 #include "boxes.h"
 
-#ifndef MOD_SAVE_DIR
-	#define MOD_SAVE_DIR "/tmp/mod-save-dir"
-#endif
-#ifndef MOD_SAVE_FILE
-	#define MOD_SAVE_FILE "/tmp/mod-save-file"
-#endif
 #define MOUNT_DIR "/floppy"
 #if !(#cpu(s390))
 #define FLOPPY_DEVICE "/dev/fd0"
@@ -121,7 +115,6 @@ int load_modules_after_boot(void)
 	DIR * dir;
 	struct dirent * dirent;
 	char * tmp;
-	char * tmp2;
 	char * already_loaded;
 	char * modules_dir;
 	char current_dir[256];
@@ -288,7 +281,6 @@ int load_modules_after_boot(void)
 		cleanquit(q);
 		return 1;
 	}
-	tmp2 = NULL; /* for the realloc */
 	i = 0; /* nb of loaded modules */
 	for (;;)
 	{
@@ -303,19 +295,8 @@ int load_modules_after_boot(void)
 			continue;
 		}
 		tmp = inputBox(_("Would you like to pass any arguments to the module?"),_("Modules arguments"),'\0');
-		tmp2 = realloc(tmp2,sizeof("/sbin/insmod -f ") + sizeof(mod_choices[ret].string) + sizeof(" ") + strlen(tmp));
-		if ( tmp2 == NULL )
-		{
-			problemBox(_("Can't allocate memory"),_("Error"));
-			cleanquit(q);
-			return 1;
-		}
-		/* launch insmod -f module.o arguments */
-		strcpy(tmp2,"/sbin/insmod -f ");
-		strcat(tmp2,mod_choices[ret].string);
-		strcat(tmp2," ");
-		strcat(tmp2,tmp);
-		if ( execlog(tmp2,LOG_INFO) )
+      sprintf(prtbuf, "/sbin/insmod -f %s %s", mod_choices[ret].string, tmp);
+		if ( execlog(prtbuf,LOG_INFO) )
 		{
 			problemBox(_("The loading has failed."),_("Error"));
 			
@@ -330,19 +311,8 @@ int load_modules_after_boot(void)
 				problemBox(_("Unable to access or create the directory used for saving the modules, can't continue"),_("Critical Error"));
 				cleanquit(q);
 			}
-			tmp2 = realloc(tmp2,sizeof("cp ") + strlen(mod_choices[ret].string) + sizeof(" ") + sizeof(MOD_SAVE_DIR));
-			if ( tmp2 == NULL )
-			{
-				problemBox(_("Can't allocate memory"),_("Error"));
-				cleanquit(q);
-				return 1;
-			}
-			/* if you have a better (=shorter) way to do this, please tell me */
-			strcpy(tmp2,"cp ");
-			strcat(tmp2,mod_choices[ret].string);
-			strcat(tmp2," ");
-			strcat(tmp2,MOD_SAVE_DIR);
-			if ( execlog(tmp2,LOG_DEBUG) )
+         sprintf(prtbuf, "cp %s %s", mod_choices[ret].string, MOD_SAVE_DIR);
+			if ( execlog(prtbuf,LOG_DEBUG) )
 			{
 				problemBox(_("Can't copy module files"),_("Error"));
 				cleanquit(q);
@@ -372,7 +342,8 @@ int load_modules_after_boot(void)
 		}
 	}
 	
-	free(tmp2);	
+   if(fd)
+      fclose(fd);
 	fdisk_reread();
 	cleanquit(q);	
 
