@@ -160,7 +160,8 @@ main_menu (void)
 #endif
 /* since this process uses lilo, we only use it with i386 */
 #if (#cpu(i386))
-		{_("Preload modules from a floppy"),	OPT_LOAD_MODULES_FROM_A_FD_AFTER_BOOT},
+		/* TRANS: keep it short */
+		{_("Preload Modules from a Floppy"),	OPT_LOAD_MODULES_FROM_A_FD_AFTER_BOOT},
 #endif
 		{_("Partition a Hard Disk"),				OPT_PARTITION_DISK},
 		{_("Initialize and Activate a Swap Partition"),		OPT_INITIALIZE_SWAP},
@@ -180,11 +181,11 @@ main_menu (void)
 		{_("Configure the Hostname"),				OPT_CONFIGURE_HOSTNAME},
 		{_("Configure the Network"),				OPT_CONFIGURE_NET},
 		{_("Install the Base System"),				OPT_INSTALL_BASE},
-#if (#cpu(alpha) || #cpu(m68k) || #cpu(i386) || #cpu(sparc)) || #cpu(powerpc)
+#if (#cpu(alpha) || #cpu(m68k) || #cpu(i386) || #cpu(sparc) || #cpu(powerpc))
 		{_("Edit Kernel Boot Parameters"),			OPT_KERNEL_APPEND},
 #endif
 		{_("Make System Bootable"),				OPT_DISK_BOOT},
-#if !(#cpu(hppa) || #cpu(s390) || #cpu(mips) || #cpu(mipsel) || #cpu(ia64) || #cpu(arm))
+#if (#cpu(alpha) || #cpu(i386) || #cpu(sparc)) 
 		{_("Make a Boot Floppy"),				OPT_FLOPPY_BOOT},
 #endif
 #if 0 /* not working yet */
@@ -332,6 +333,7 @@ main_menu (void)
 		bufT = _("You must indicate what sort of keyboard you have so that keys operate as expected.  Select \"Next\" from the menu to configure your keyboard.");
 		bufN = _("Configure the Keyboard");
 #if ( #cpu(i386) )
+		/* TRANS: keep it short */ 
 		bufA = _("Preload essential modules from a floppy");
 		alternate_action = load_modules_after_boot;
 #endif
@@ -375,7 +377,7 @@ main_menu (void)
 		 */
 		next_action      = partition_disk;
 		alternate_action = no_swap;
-		bufT = _("A swap partition is strongly recommended to provide virtual memory for your system, yet no swap partitions were detected.  Selecting \"Next\" will start the partitioning program.  Use that to create \"Linux native\" and \"Linux swap\" partitions on your disks.  If you don't want a swap partition, select \"Alternative\".");
+		bufT = _("A swap partition is strongly recommended to provide virtual memory for your system, yet none was detected.  Selecting \"Next\" will start the partitioning program.  Use that to create \"Linux native\" and \"Linux swap\" partitions on your disks.  If you don't want a swap partition, select \"Alternate\".");
 		bufN = _("Partition a Hard Disk");
 		bufA = _("Do Without a Swap Partition");
 #if ( #cpu(i386) )
