@@ -1,6 +1,6 @@
 /*
  * Description  Net-fetch module implementation.
- * CVS          $Id: net-fetch.c,v 1.38 2000/08/13 13:18:37 joey Exp $
+ * CVS          $Id: net-fetch.c,v 1.61 2002/03/17 03:48:15 dwhedon Exp $
  * Author       Marcel Harkema <marcel@debian.org>
  *
  * Copyright (C) 1999, 2000 Marcel Harkema
@@ -26,6 +26,9 @@
 #include <sys/param.h>
 #include <time.h>
 #include <assert.h>
+#include <regex.h>
+#include <sys/types.h>
+#include <sys/wait.h>
 
 #include <newt.h>
 
@@ -34,38 +37,24 @@
 #include "lang.h"
 #include "util.h"
 
-/* Include headers of net-fetch modules. */
-#include "http-fetch.h"
+#define WGET "/usr/bin/wget"
 
 /*
  * Private data-structures and variables.
  */
 
-struct _nf_endpoint {
-  char                *hostname;
-  unsigned short int   port;
-};
-
-struct _nf_state {
-  char                 initialized;
-  char                *method;
-  struct _nf_endpoint  server;
-  struct _nf_endpoint  proxy;
-  char                *path;        /* debian/dists/potato/ ... */
-};
-static struct _nf_state nf_state;
+struct _nf_state nf_state;
 
 struct _nf_transport {
   char                *url_prefix;
   unsigned short int   default_port;
-  fetchfile_funtype    fetchfile_fn;
 };
 
+
 struct _nf_transport nf_transports[] = {
-  { "http",  80, nf_http_fetchfile       },
-//{ "http",  80, nf_snarf_http_fetchfile },
-//{ "ftp",   21, nf_snarf_ftp_fetchfile  },
-  { NULL,    0,  NULL                    }
+  { "http",  80 },
+  { "ftp",   21 },
+  { NULL,    0  }
 };
 
 #ifdef _TESTING_
@@ -85,7 +74,6 @@ extern void   get_subarch_name  (void);
  */
 
 #define SERIES_OS    1
-#define SERIES_BASE  2
 
 static int nf_install(int series);
 
@@ -131,30 +119,12 @@ nf_extract_drivers(const char *filename_)
   return install_from_file(filename, _("Drivers"));
 }
 
-
 int
 nf_install_os(void)
 {
   return nf_install(SERIES_OS);
 }
 
-
-static int
-nf_extract_base(const char *filename_)
-{
-  char filename[MAXPATHLEN];
-  snprintf(filename, sizeof(filename), "%s", target_path(filename_));
-  return extract_from_file(filename, _("Base System"));
-}
-
-
-int
-nf_install_base(void)
-{
-  return nf_install(SERIES_BASE);
-}
-
-
 static int
 nf_method_lookup(char *method)
 {
@@ -222,9 +192,10 @@ nf_parse_server_url(char *url)
   }
 
   if ((method = nf_method_lookup(nf_state.method)) < 0) {
-    snprintf(buf, sizeof buf - 1, _("Unknown protocol '%s' used in the URL."), nf_state.method);
-    strcat(buf, "\n");
-    problemBox(buf, "Unknown Protocol");
+    snprintf(prtbuf, sizeof(prtbuf) - 1,
+	     _("Unknown protocol '%s' used in the URL."), nf_state.method);
+    strcat(prtbuf, "\n");
+    problemBox(prtbuf, "Unknown Protocol");
     free(buf);
     return 1;
   }
@@ -266,16 +237,23 @@ nf_select_server(void)
              nf_state.method, nf_state.server.hostname, nf_state.server.port, nf_state.path);
   }
 
-  l[0] = newtLabel(1, height + 2, _("Download URL"));
-  e[0] = newtEntry(14, height + 2, txtbuf, 58, &s[0], NEWT_FLAG_SCROLL);
+  {
+    const char *l1 = _("Download URL");
+    const char *l2 = _("Proxy");
+    const char *l3 = _("Proxy Port");
+    int x = max(strwidth(l1), strwidth(l2));
+    
+    l[0] = newtLabel(1, height + 2, l1);
+    e[0] = newtEntry(x + 2, height + 2, txtbuf, 70 - x, &s[0], NEWT_FLAG_SCROLL);
+    
+    l[1] = newtLabel(1, height + 4, l2);
+    e[1] = newtEntry(x + 2, height + 4, nf_state.proxy.hostname, 60 - strwidth(l3) - x, &s[1], NEWT_FLAG_SCROLL);
+    l[2] = newtLabel(65 - strwidth(l3), height + 4, l3);
+    snprintf(txtbuf, sizeof txtbuf - 1, "%d", nf_state.proxy.port);
+    e[2] = newtEntry(66, height + 4, txtbuf, 6, &s[2], NEWT_FLAG_SCROLL);
+  }
 
-  l[1] = newtLabel(1, height + 4, _("Proxy"));
-  e[1] = newtEntry(14, height + 4, nf_state.proxy.hostname, 40, &s[1], NEWT_FLAG_SCROLL);
-  l[2] = newtLabel(58, height + 4, _("Port"));
-  snprintf(txtbuf, sizeof txtbuf - 1, "%d", nf_state.proxy.port);
-  e[2] = newtEntry(66, height + 4, txtbuf, 6, &s[2], NEWT_FLAG_SCROLL);
-
-  b1 = newtCompactButton(19, height + 6, _("Ok"));
+  b1 = newtCompactButton(19, height + 6, _("OK"));
   b2 = newtCompactButton(29, height + 6, _("Cancel"));
   b3 = newtCompactButton(42, height + 6, _("Help"));
 
@@ -288,7 +266,7 @@ nf_select_server(void)
     nf_state.proxy.hostname = strdup(s[1]);
     nf_state.proxy.port = atoi(s[2]);
     if (ans == b3) {
-      problemBox(_("Debian supports installing drivers and the base system over the Internet.  Currently, only HTTP retrieval is supported.\nPlease enter some information so that the files can be retrieved.\n\nDownload URL: the URL of the directory containing the file to be downloaded.  The default location should work on Debian standard servers.\nProxy: a proxy server to use to fetch the URL, or \"none\" if you don't need one.\nPort: the port that the proxy server listens on."),
+      problemBox(_("Debian supports installing drivers and the base system over the Internet.  Currently, only HTTP retrieval is supported.\nPlease enter some information so that the files can be retrieved.\n\nDownload URL: the URL of the directory containing the file to be downloaded.  The default location should work on Debian standard servers.\nProxy: a proxy server to use to fetch the URL, or \"none\" if you don't need one.\nProxy Port: the port that the proxy server listens on."),
                  _("Help For Network Installation"));
     }
     else if (ans == b2 || nf_parse_server_url(s[0]) == 0) {
@@ -306,144 +284,53 @@ nf_select_server(void)
   if (ans == b2)  /* cancel */
     return 1;
 
-  return 0;
-}
-
-
-/*
- * Widget for displaying download progress.
+/* 
+ * write the HTTP_PROXY user config, as used by base-config 
+ * This may get written several times, but the last entry is
+ * likely to be correct and that's what base-config will 
+ * end up using.
+ * 
+ * Also set some environmental vars since wget grabs 
+ * http_proxy/ftp_proxy if necessary 
  */
+  if ( strcmp(nf_state.proxy.hostname, "none") != 0 ) {
+      int rv;
+      char *ptr;
+     
+      /* maybe user put a http:// or ftp:// in the proxy hostname,
+       * silently remove it if necessary. */
+      ptr = strstr(nf_state.proxy.hostname, "://");
+      if (ptr) {
+	  char *temp;
+	  temp = nf_state.proxy.hostname;
+	  nf_state.proxy.hostname = strdup(ptr+3); /* the actual hostname */
+	  free (temp);
+      }
 
-static int
-nf_progress_scaleBox(const char *text,
-                     const char *title,
-		     const long value,
-		     const int action)
-{
-  static newtComponent tx = NULL, scale = NULL, stopbtn = NULL, f = NULL;
-
-  switch (action) {
-    case SCALE_CREATE:
-      if (f)
-        return -1;
-      newtCenteredWindow(72, 14, title);
-      f = newtForm(NULL, NULL, 0);
-      tx = newtTextbox(1, 1, 71, 8, NEWT_FLAG_WRAP);
-      newtTextboxSetText(tx, text);
-      scale = newtScale(4, 10, 62, value);
-      stopbtn = newtCompactButton(33, 12, _("Stop"));
-      newtFormAddComponents(f, tx, scale, stopbtn, NULL);
-      newtDrawForm(f);
-      newtRefresh();
-      break;
-
-    case SCALE_REFRESH:
-      if (!f)
-        return -1;
-      newtTextboxSetText(tx, text);
-      newtDrawForm(f);
-      newtScaleSet(scale, value);
-      newtRefresh();
-      break;
-
-    case SCALE_DELETE:
-      if (!f)
-        return -1;
-      newtPopWindow();
-      newtFormDestroy(f);
-      f = NULL;
-      break;
-  }
-
-  return 0;
-}
-
-
-static void
-nf_progress_display(const char *basename, const off_t bytes)
-{
-  static char   txtbuf[2048];
-  static int    len;
-  static time_t starttime;
-  static off_t  bytes_total;
-
-  if (basename != NULL) {
-    starttime = time(NULL);
-    bytes_total = bytes;
-
-    len = snprintf(txtbuf, sizeof txtbuf - 1,
-                   _("Fetching    %s\n"
-                     "Server      %s://%s:%d/\n"
-                     "Path        %s\n"),
-                   basename, nf_state.method, nf_state.server.hostname,
-                   nf_state.server.port, nf_state.path);
-
-    if (strcmp(nf_state.proxy.hostname, "")
-        && strcmp(nf_state.proxy.hostname, "none")) {
-      len += snprintf(txtbuf + len, sizeof txtbuf - len - 1,
-                      _("Proxy       %s://%s:%d/\n"),
-                      nf_state.method, nf_state.proxy.hostname, nf_state.proxy.port);
-    }
-    else {
-      len += snprintf(txtbuf + len, sizeof txtbuf - len - 1, _("Proxy       none\n"));
-    }
-
-    len += snprintf(txtbuf + len, sizeof txtbuf - len - 1,
-                    _("File size   %ld bytes\n"), bytes_total);
-
-    nf_progress_scaleBox(txtbuf, _("Installing From Network"), bytes_total, SCALE_CREATE);
+      snprintf(txtbuf, sizeof txtbuf, "%s://%s:%d",
+	      nf_state.method,
+	      nf_state.proxy.hostname,
+	      nf_state.proxy.port);
+      if (strcmp (nf_state.method, "ftp") == 0) {
+	  rv = setenv("ftp_proxy", txtbuf, 1);
+	  write_userconfig("FTP_PROXY", txtbuf);
+      } else {
+	  rv = setenv("http_proxy", txtbuf, 1);
+	  write_userconfig("HTTP_PROXY", txtbuf);
+      }
+      if (rv == -1){
+	  problemBox(_("failure"), _("Could not set http/ftp proxy."));
+	  return 1;
+      }
   }
   else {
-    time_t seconds;
-    char txteta[64];
-
-    seconds = time(NULL) - starttime;
-
-    if (seconds >= 2 && bytes > 0) {
-      long lh, lm, ls;
-
-      ls = (bytes_total - bytes) / (bytes / seconds);
-      lm = ls / 60;
-      ls = ls % 60;
-      lh = lm / 60;
-      lm = lm % 60;
-
-      snprintf(txteta, sizeof txteta - 1,
-               "%02ldH:%02ldM:%02ldS", lh, lm, ls);
-    }
-    else {
-      snprintf(txteta, sizeof txteta - 1, "--H:--M:--S");
-    }
-
-    snprintf(txtbuf + len, sizeof txtbuf - len - 1,
-             _("Bytes read  %ld bytes\n"
-               "Rate        %ld bytes/sec\n"
-               "ETA         %s\n"),
-             bytes, seconds > 0 ? bytes / seconds : 0, txteta);
-
-    nf_progress_scaleBox(txtbuf, NULL, bytes, SCALE_REFRESH);
+      unsetenv("http_proxy");
+      unsetenv("ftp_proxy");
+      write_userconfig("FTP_PROXY", NULL);
+      write_userconfig("HTTP_PROXY", NULL);
   }
-}
-
-
-void
-nf_progress_open(const char *basename, const off_t bytes_total)
-{
-  nf_progress_display(basename, bytes_total);
-}
-
-
-void
-nf_progress_update(const off_t bytes_read)
-{
-  nf_progress_display(NULL, bytes_read);
-}
-
-
-void
-nf_progress_close(void)
-{
-  nf_progress_scaleBox(NULL, NULL, 0, SCALE_DELETE);
+  
+  return 0;
 }
 
 
@@ -462,6 +349,9 @@ nf_initialize(void)
   // http://http.us.debian.org/debian/dists/potato/main/disks-$arch/current/
   nf_state.method = strdup("http");
   nf_state.server.hostname = strdup("http.us.debian.org");
+#ifdef USE_LANGUAGE_CHOOSER
+  find_opt_server(nf_state.server.hostname);
+#endif  
   nf_state.server.port = 80;
   nf_state.proxy.hostname = strdup("none");
   nf_state.proxy.port = 8080;
@@ -478,38 +368,120 @@ nf_initialize(void)
 }
 
 
-void
-nf_finalize(void)
-{
-  if (!nf_state.initialized)
-    return;
-
-  nf_state.initialized = 0;
-
-  free(nf_state.method); nf_state.method = NULL;
-  free(nf_state.server.hostname); nf_state.server.hostname = NULL;
-  free(nf_state.proxy.hostname); nf_state.proxy.hostname = NULL;
-  free(nf_state.path); nf_state.path = NULL;
-}
+/*
+  exec wget as indicated by argv
 
+  read the progress bar on stderr and convert it into a pretty GUI
+  progress bar like the rest of dbootstrap.
 
+  Do we want ETA as well, I removed it to save space since the
+  progress bar already gives a good idea.
+  if ((rv = regcomp (&eta, "[[:digit:]]*:[[:digit:]]*[[:space:]]*ETA", 0)) != 0)
+*/
 static int
-nf_fetchfile(char *remote_filename, char *local_filename)
-{
-  int ti;
+nf_fetchfile (char *remote_filename, char *local_filename)
+{  
+  int from_wget[2];
+  char buf[256];
+  pid_t pid;
+  int bytes, status;
+  regex_t percent;
+  regmatch_t pmatch_percent[1];
+  char *argv[5];
+  char url[128];
+  char msg[128];
+  char *full_remote_filename;
 
-  ti = nf_method_lookup(nf_state.method);
+  full_remote_filename = concat_paths (nf_state.path, remote_filename);
 
-  assert(ti >= 0);
-  assert(nf_transports[ti].fetchfile_fn != NULL);
+  argv[0] = WGET;
+  argv[1] = "-O";
+  argv[2] = local_filename;
+  snprintf (url, sizeof url, "%s://%s:%d/%s",
+	    nf_state.method, 
+	    nf_state.server.hostname, 
+	    nf_state.server.port,
+	    full_remote_filename);
+  argv[3] = url;
+  argv[4] = NULL;
+  
+  snprintf(msg, sizeof msg, 
+           "Host:  %s://%s:%d\nFile:  %s\n", 
+	   nf_state.method,
+	   nf_state.server.hostname, nf_state.server.port,
+	   full_remote_filename);
+
+  free(full_remote_filename);
+  
+  if ( strcmp(nf_state.proxy.hostname, "none") != 0 ) {
+      snprintf(msg + strlen(msg), sizeof msg - strlen(msg),
+	      "Proxy: %s:%d", nf_state.proxy.hostname, 
+	      nf_state.proxy.port);
+  }
+  pipe (from_wget);
+  if ((pid = fork ()) == 0)
+    {
+      close (from_wget[0]);
+      if (dup2 (from_wget[1], 2) == -1)
+	perror ("dup2");
+
+      if (execv (argv[0], argv) != 0)
+	perror ("execv");
+      return -1;
+    }
+  else if (pid == -1)
+    {
+      perror ("fork");
+      return -1;
+    }
+
+  close (from_wget[1]);
+
+  if (regcomp (&percent, "[^[:space:]]*%", 0) != 0) {
+      fprintf(stderr, "recomp failed.\n");
+      return -1;
+  }
+
+  boxProgress (PROGRESS_INIT, _("Downloading"));
+  boxProgress (PROGRESS_SETTEXT, msg);
+  
+  while ((bytes = read (from_wget[0], buf, sizeof (buf))) > 0)
+    {
+      buf[bytes] = '\0';
+      if (regexec (&percent, buf, 1, pmatch_percent, 0) != REG_NOMATCH)
+	{
+	  snprintf (buf, sizeof buf, "%d 100",
+		    atoi (buf + pmatch_percent[0].rm_so));
+	  boxProgress (PROGRESS_UPDATE, buf);
+	}
+    }
+
+  boxProgress (PROGRESS_CLOSE, NULL);
+  regfree (&percent);
+
+ if (waitpid(pid, &status, WNOHANG)  && (WIFEXITED(status) != 0 ))
+   {
+    int rv = WEXITSTATUS(status);
+    if (rv != 0 ) 
+      {
+        /* the last line from wget should contain some
+	 * diagnostic info */
+	vaproblemBox (_("An Error occured"), "%s%s\n", msg, buf);
+        return rv;
+       }
+     return 0;
+   }
+ else 
+   {
+     /* no child available, try to kill it */
+     kill(SIGKILL, pid);
+     return 1;
+    }
+
+  return 0;
 
-  return nf_transports[ti].fetchfile_fn(nf_state.server.hostname, nf_state.server.port,
-                                        nf_state.proxy.hostname, nf_state.proxy.port,
-                                        nf_state.path,
-                                        remote_filename, local_filename);
 }
 
-
 static int
 nf_install(int series)
 {
@@ -528,7 +500,6 @@ nf_install(int series)
   files_to_fetch[] = {
     { "rescue.bin",   kernel_image_path, nf_extract_kernel,  SERIES_OS   },
     { "drivers.tgz",  drivers_path,      nf_extract_drivers, SERIES_OS   },
-    { "base2_2.tgz",  BASETGZ,           nf_extract_base,    SERIES_BASE },
     { NULL,           NULL,              NULL,               0           }
   };
 
@@ -562,13 +533,6 @@ nf_install(int series)
       /* NOTREACHED */
   }
 
-  if ( strcmp(nf_state.proxy.hostname, "none") != 0 ) {
-    /* write the HTTP_PROXY user config, as used by base-config */
-    snprintf(txtbuf, sizeof txtbuf, "http://%s:%d/", 
-             nf_state.proxy.hostname, nf_state.proxy.port);
-    write_userconfig("HTTP_PROXY", txtbuf);
-  }
-
   /*
    * First fetch the required files.
    */
@@ -576,7 +540,8 @@ nf_install(int series)
     if (series != files_to_fetch[i].series)
       continue;
 
-    snprintf(filename, sizeof filename - 1, "/tmp/%s", files_to_fetch[i].local);
+    snprintf(filename, sizeof filename - 1, target_path("/tmp/%s"), 
+      files_to_fetch[i].local);
 
     INFOMSG("retrieving %s from %s", filename, files_to_fetch[i].remote);
 
@@ -586,7 +551,7 @@ nf_install(int series)
       return 1;
     }
 
-    INFOMSG("sucessfully installed %s", filename);
+    INFOMSG("successfully retrieved %s", filename);
   }
 
   /*
@@ -598,16 +563,47 @@ nf_install(int series)
 
     snprintf(filename, sizeof filename - 1, "/tmp/%s", files_to_fetch[i].local);
 
+    INFOMSG("installing %s", filename);
+
     if (files_to_fetch[i].install_fn(filename) != 0) {
       vaproblemBox(_("Problem"), _("Installation of the file '%s' failed."), filename);
       return 1;
     }
+
+    INFOMSG("successfully installed %s", filename);
   }
 
   return 0;
 }
 
 
+
+#ifdef _TESTING_
+int
+main ()
+{
+  LOAD_TRMFILE ("test.trm");
+  get_kver ();
+  boxInit ();
+
+  nf_initialize();
+  nf_select_server ();  
+
+  nf_fetchfile ("ls-lR.gz", "foo");
+
+  boxFinished();
+
+  return 0;
+}
+#endif /* _TESTING_ */
+
+
+
+#if 0
+
+/* I didn't remove this because I'm nice, but it doesnt' compile anymore.
+ * dwhedon@debian.org */
+
 #ifdef _TESTING_
 /*
  * Source code for testing net-fetch.  This may require some tweaking on
@@ -625,15 +621,16 @@ install_from_file (const char *filename, const char *descr)
     snprintf (instdir, sizeof instdir - 1, "%s/drivers", tmpdir);
     if (!NAME_ISDIR (tmpdir, &statbuf))
       {
-        if (!mkdir (tmpdir, 01777))
+        if (!mkdir (tmpdir, 0777))
           {
             chown (tmpdir, 0, 3); /* root_uid= 0 , sys_gid= 3 */
+	    chmod (tmpdir, 01777);
           }
       }
 
     if (!NAME_ISDIR (instdir, &statbuf))
       {
-        if (!mkdir (instdir, 01777))
+        if (!mkdir (instdir, 0777))
           {
             chown (instdir, 0, 3); /* root_uid= 0 , sys_gid= 3 */
           }
@@ -758,7 +755,7 @@ extract_from_file (const char *fil, const char *descr)
   {
     int status;
 
-    sprintf (prtbuf, "The %s is being extracted from %s...", descr, fil);
+    sprintf (prtbuf, "Extracting %s from %s...", descr, fil);
     pleaseWaitBox (prtbuf);
 
     chdir (target_path (""));
@@ -793,7 +790,11 @@ main (int argc, char *argv [])
 
     if (bootargs.disksize == NULL)
       {
+#if #cpu(mips) && defined (MIPSEL)
+        bootargs.disksize = "2.88";
+#else
         bootargs.disksize = "1.44";
+#endif
       }
     bootargs.flavor = "compact"; // compact, safe, standard
     bootargs.isquiet = 0;
@@ -822,3 +823,5 @@ main (int argc, char *argv [])
     return EXIT_SUCCESS;
   }
 #endif /* _TESTING_ */
+
+#endif
