@@ -676,26 +676,31 @@ mount_partition (struct fdisk_partition *partition)
     if (fdisk_find_partition_by_mntpoint("/target/boot") == NULL)
     {
       mount_points[i  ].tag    = "/boot";
+      /* TRANS: keep this under one line (about 63 characters) */
       mount_points[i++].string = _("A small (5-10Mb) partition at the start of the disk.");
     }
     if (fdisk_find_partition_by_mntpoint("/target/usr") == NULL)
     {
       mount_points[i  ].tag    = "/usr";
+      /* TRANS: keep this under one line (about 63 characters) */
       mount_points[i++].string = _("A large partition where most software resides.");
     }
     if (fdisk_find_partition_by_mntpoint("/target/var") == NULL)
     {
       mount_points[i  ].tag    = "/var";
+      /* TRANS: keep this under one line (about 63 characters) */
       mount_points[i++].string = _("Variable data such as mail spools and databases.");
     }
     if (fdisk_find_partition_by_mntpoint("/target/home") == NULL)
     {
       mount_points[i  ].tag    = "/home";
+      /* TRANS: keep this under one line (about 63 characters) */
       mount_points[i++].string = _("User home directories.");
     }
     if (i > 0)
     {
       mount_points[i].tag    = _("Other");
+      /* TRANS: keep this under one line (about 63 characters) */
       mount_points[i].string = _("Enter name of a different mount point.");
     }
  
@@ -784,6 +789,8 @@ mount_partition (struct fdisk_partition *partition)
       else
          strcpy(e2fsmagic, "2");
 
+      status = 1;
+
       if (!(strcmp(xfsmagic, "XFSB"))) { /* XFS */
 #if #cpu(powerpc)
 	if (verify_powerpc_mount(mount_point, "xfs"))
@@ -795,35 +802,19 @@ mount_partition (struct fdisk_partition *partition)
       }
 
       /* thanks to journey@jps.net for the clue about the reiserfs magic number */
-      else if (!(strcmp(shfsmagic, "ReIsErFs") && strcmp(shfsmagic, "ReIsEr2Fs"))) /* reiserfs */
+      if (status && !(strcmp(shfsmagic, "ReIsErFs") && strcmp(shfsmagic, "ReIsEr2Fs"))) /* reiserfs */
 	{
 #if #cpu (powerpc)
 	if (verify_powerpc_mount(mount_point, "reiserfs"))
 	  return 1;
 #endif
-#if 0
-	  snprintf(prtbuf, sizeof(prtbuf), _("The \"notail\" option is required on the /boot "
-					     "partition for LILO to work properly, and is also "
-					     "useful for some other partitions (such as qmail mail "
-					     "queue directories).\nIf you do not plan on using LILO "
-					     "as a boot loader, you may say No.\n\n"
-					     "If in doubt, say yes. It is the safe thing to do.\n\n"
-					     "Do you want to mount %s (%s) with the \"notail\" flag?"),
-		   mount_point, partition->name);
-	  status = yesNoBox(prtbuf, _("Mount with \"notail\"?"));
-	  if (status == DLG_YES)
-	    {
-	      addnotail (partition->name);
-	      addnotail (real_mount_point);
-	    }
-#endif	  
 	  INFOMSG("Mounting ReiserFS partition %s on %s", partition->name, real_mount_point);
 	  snprintf(prtbuf, sizeof(prtbuf), "mount -t reiserfs -o %s %s %s",
 		   status==DLG_YES ? "defaults,notail" : "defaults",
 		   partition->name, real_mount_point);
 	  status = execlog(prtbuf, LOG_INFO);
 	}
-      else if (is_ext3) { /* ext2/ext3 */
+      else if (status && is_ext3) { /* ext2/ext3 */
 	if (!strcmp(mount_point, "/boot")) {
 	  if (
 #if #cpu (powerpc) /* OldWorld PowerPC must use ext2 for /boot */
@@ -848,7 +839,7 @@ mount_partition (struct fdisk_partition *partition)
 	  status = execlog(prtbuf, LOG_INFO);
 	}
       }
-      else { /* ext2, ext3 not supported */
+      else if (status) { /* ext2, ext3 not supported */
 	INFOMSG("Mounting ext2 partition %s on %s", partition->name, real_mount_point);
 	snprintf(prtbuf, sizeof(prtbuf), "mount -t ext2 %s %s",
 		 partition->name, real_mount_point);
@@ -863,6 +854,10 @@ mount_partition (struct fdisk_partition *partition)
     }
   }
   else { /* not a Linux Native partition, use partition type to determine fstype. */
+#if #cpu(powerpc)
+       if (verify_powerpc_mount(mount_point, type))
+         return 1;
+#endif
     /* if libfdisk reported msdos but we have vfat support, use vfat */
     if(strcmp(type,"msdos")==0 && !is_filesystem_supported("vfat"))
        type="vfat";
@@ -871,6 +866,12 @@ mount_partition (struct fdisk_partition *partition)
     status = execlog(prtbuf, LOG_INFO);
   }
   
+  if(status) {
+     INFOMSG("Last try: mounting partition %s on %s with FS type autodetection", partition->name, real_mount_point);
+     snprintf(prtbuf, sizeof(prtbuf), "mount -t auto %s %s", partition->name, real_mount_point);
+     status = execlog(prtbuf, LOG_INFO);
+  }
+  
   if (status) {
     perrorBox(_("Mount failed"));
     free(real_mount_point);
@@ -1105,7 +1106,7 @@ int init_reiserfs (void) {
     if (yesNoBox( _("The running kernel supports the new ReiserFS format 3.6. "
 				       "This version should be more stable than the default version 3.5.\n\n"
 				       "Unfortunately, stable kernel versions "
-				       "prior to version 2.4.1 cannot mount a such filesystem.  "
+				       "prior to version 2.4.1 cannot mount such a filesystem. "
 				       "Would you like to use the new version?\n\nIf you plan to run kernel 2.2.x (with ReiserFS patches), say No.") , _("Use ReiserFS format 3.6?")) == DLG_NO)
         rfsver=1;
   }
@@ -1125,7 +1126,7 @@ int init_reiserfs (void) {
   }
 
   INFOMSG("Initializing partition %s as ReiserFS", p->name);
-  snprintf(prtbuf, sizeof(prtbuf), "mkreiserfs -q --format %s -f -f %s", (rfsver == 1 ? "3.5" : "3.6"), p->name);
+  snprintf(prtbuf, sizeof(prtbuf), "mkreiserfs --format %s -f -f %s", (rfsver == 1 ? "3.5" : "3.6"), p->name);
   boxSuspend();
   if (!cflag)
     printf(CLEAR);
@@ -1158,13 +1159,12 @@ int init_linux (void) {
       snprintf(bootnotes, sizeof(bootnotes), "\n");
 #elif #cpu (sparc)
     if (is_xfs)
-      snprintf(bootnotes, sizeof(bootnotes), _("\nNote that SILO can only read Ext2 filesytems.  "
+      snprintf(bootnotes, sizeof(bootnotes), _("\nNote that SILO can only read Ext2/Ext3 filesytems.  "
 					       "You must use the Ext2 filesystem for your root "
 					       "partition.  Also note that you must not create an "
 					       "XFS filesystem on the first partition of the disk.\n\n"));
     else
-      snprintf(bootnotes, sizeof(bootnotes), _("\nNote that SILO can only read Ext2 filesytems.  You "
-					       "must use the Ext2 filesystem for your root partition.\n\n"));
+      snprintf(bootnotes, sizeof(bootnotes), "\n");
 #elif #cpu (i386)
     if (is_xfs)
       snprintf(bootnotes, sizeof(bootnotes), _("\nNote that you must not install LILO onto an XFS partition.  "
@@ -1177,18 +1177,22 @@ int init_linux (void) {
 #endif
 
     fs_list[i  ].tag    = "Ext2";
+    /* TRANS: keep this under one line (about 63 characters) */
     fs_list[i++].string = _("Traditional GNU/Linux filesystem");
 
     if (is_ext3) {
       fs_list[i  ].tag    = "Ext3";
+      /* TRANS: keep this under one line (about 63 characters) */
       fs_list[i++].string = _("Next Generation of Ext2, a journaling filesystem");
     }
     if (is_xfs) {
       fs_list[i  ].tag    = "XFS";
+      /* TRANS: keep this under one line (about 63 characters) */
       fs_list[i++].string = _("SGI's advanced, fast, mature journaling filesystem");
     }
     if (is_reiserfs) {
       fs_list[i].tag      = "ReiserFS";
+      /* TRANS: keep this under one line (about 63 characters) */
       fs_list[i++].string = _("Younger less mature journaling filesystem");
     }
 
