@@ -3,7 +3,7 @@
 # This program can be licensed with GPL v2 or above
 # Written for the boot-floppy translators...
 
-open (FILE,$ARGV[0]);
+open (FILE,$ARGV[0]) || die("file '" . $ARGV[0] . "' cannot be opened\n");
 $a=0;
 $line=0;
 while ($olvas=<FILE>)
