@@ -66,7 +66,7 @@ int reboot_system (void) {
 	fclose(fd);
         if(bootmagic != '\0')
         {
-          sprintf(prtbuf, _("Please note that the drive %s contains a bootable CD-ROM. If you enabled the cdboot option in your BIOS, you should remove the disk; otherwise, you will start the installation again and again."), dev);
+          sprintf(prtbuf, _("Please note that the drive %s contains a bootable CD-ROM. If your BIOS is configured to boot from the CD, you should remove the CD-ROM; otherwise, you will start the installation again and again."), dev);
           problemBox(prtbuf,  _("Please remove the CD"));
 
         }
