@@ -569,6 +569,14 @@ static struct DEVICE_BLOCK {
     { 57 << 8,   2, 64 },	/* hdk      - hdl       */
     { 65 << 8, 112, 16 },	/* sdq      - sddx      */
     { 72 << 8, 128, 16 },	/* ida/c0d0 - ida/c7d15 */
+    { 80 << 8,  16, 16 },	/* i2o/hda  - i2o/hdp */
+    { 81 << 8,  16, 16 },	/* i2o/hdq  - i2o/hdaf */
+    { 82 << 8,  16, 16 },	/* i2o/hdag  - i2o/hdav */
+    { 83 << 8,  16, 16 },	/* i2o/hdaw  - i2o/hdbl */
+    { 84 << 8,  16, 16 },	/* i2o/hdbm  - i2o/hdcb */
+    { 85 << 8,  16, 16 },	/* i2o/hdcc  - i2o/hdcr */
+    { 86 << 8,  16, 16 },	/* i2o/hdcs  - i2o/hddh */
+    { 87 << 8,  16, 16 },	/* i2o/hddi  - i2o/hddx */
     { 94 << 8,  26,  4 },	/* dasda    - dasdz     */
     {104 << 8, 256, 16 },       /* cciss/c0d0 - cciss/c7d15 */
     {114 << 8,   8, 16 },       /* ataraid/d0 - ataraid/d7 */
