@@ -22,6 +22,11 @@
  * frequently the case with the nr_sects and start_sect partition
  * table entries.
  */
+#include <linux/version.h>
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)) && defined __powerpc__
+#define __KERNEL__
+#endif
+
 #include <asm/unaligned.h>
 
 #define SYS_IND(p)	(get_unaligned(&p->sys_ind))
@@ -326,7 +331,7 @@ int get_kernel_revision(void)
 int parse_msdos_partition(char *device, int fd)
 {
     int i, minor = 1;
-    struct partition *p;
+    struct partition *p, *bsd_p = NULL;
     unsigned char data[512];
     int kernel_version = get_kernel_revision();
  
@@ -347,8 +352,8 @@ int parse_msdos_partition(char *device, int fd)
 	/* if kernel version is less than version 2.4.0 */
 	if (kernel_version < (2*65536 + 4*256)) {
 #if HAVE_BSD_DISKLABEL
-	    if (SYS_IND(p) == BSD_PARTITION) {
-                bsd_disklabel_partition(device, fd, START_SECT(p));
+	    if (SYS_IND(p) == BSD_PARTITION && bsd_p == NULL) {
+		bsd_p = p;
             }
 #endif
 #if HAVE_SOLARIS_X86_PARTITION
@@ -363,6 +368,9 @@ int parse_msdos_partition(char *device, int fd)
 	}
     }
 
+    if (kernel_version < (2*65536 + 4*256) && bsd_p != NULL)
+	bsd_disklabel_partition(device, fd, START_SECT(bsd_p));
+
     /* if kernel is 2.4 or better */
     if (kernel_version >= (2*65536 + 4*256)) {
 #if HAVE_BSD_DISKLABEL | HAVE_SOLARIS_X86_PARTITION
